Index: dvblast.c
===================================================================
--- dvblast.c	(rvision 17)
+++ dvblast.c	(copie de travail)
@@ -49,6 +49,7 @@
 int i_fenum = 0;
 int i_frequency = 0;
 int i_srate = 27500000;
+int i_satnum = 0;
 int i_voltage = 13;
 int b_tone = 0;
 int i_bandwidth = 8;
@@ -188,6 +189,7 @@
     msg_Raw( NULL, "    -q: be quiet (less verbosity, repeat or use number for even quieter)" );
     msg_Raw( NULL, "    -v: voltage to apply to the LNB (QPSK)" );
     msg_Raw( NULL, "    -p: force 22kHz pulses for high-band selection (DVB-S)" );
+    msg_Raw( NULL, "    -S: satellite number for diseqc" );
     msg_Raw( NULL, "    -m: DVB-C  qpsk|qam_16|qam_32|qam_64|qam_128|qam_256 (default qam_auto)" );
     msg_Raw( NULL, "        DVB-T  qam_16|qam_32|qam_64|qam_128|qam_256 (default qam_auto)" );
     msg_Raw( NULL, "        DVB-S2 qpsk|psk_8 (default legacy DVB-S)" );
@@ -209,7 +211,7 @@
 
     msg_Warn( NULL, "restarting" );
 
-    while ( ( c = getopt(i_argc, pp_argv, "q::c:r:t:o:i:a:n:f:s:v:pb:m:uUd:eh")) != (char)EOF )
+    while ( ( c = getopt(i_argc, pp_argv, "q::c:r:t:o:i:a:n:f:s:S:v:pb:m:uUd:eh")) != (char)EOF )
     {
         switch ( c )
         {
@@ -277,6 +279,10 @@
             i_srate = strtol( optarg, NULL, 0 );
             break;
 
+        case 'S':
+            i_satnum = strtol( optarg, NULL, 0 );
+            break;
+
         case 'v':
             i_voltage = strtol( optarg, NULL, 0 );
             break;
Index: dvblast.h
===================================================================
--- dvblast.h	(rvision 18)
+++ dvblast.h	(copie de travail)
@@ -88,6 +88,7 @@
 extern int i_fenum;
 extern int i_frequency;
 extern int i_srate;
+extern int i_satnum;
 extern int i_voltage;
 extern int b_tone;
 extern int i_bandwidth;
Index: dvb.c
===================================================================
--- dvb.c	(rvision 19)
+++ dvb.c	(copie de travail)
@@ -743,14 +743,55 @@
     /* Wait for at least 15 ms. */
     msleep(15000);
 
+    /* Diseqc */
+    if ( i_satnum > 0 && i_satnum < 5 )
+    {
+        /* digital satellite equipment control,
+         * specification is available from http://www.eutelsat.com/
+         */
+
+        struct diseqc_cmd_t
+        {
+            struct dvb_diseqc_master_cmd cmd;
+            uint32_t wait;
+        } cmd =  { {{0xe0, 0x10, 0x38, 0xf0, 0x00, 0x00}, 4}, 0 };
+
+        /* param: high nibble: reset bits, low nibble set bits,
+         * bits are: option, position, polarization, band
+         */
+        cmd.cmd.msg[3] = 0xf0 /* reset bits */
+                          | (((i_satno - 1) * 4) & 0xc)
+                          | (fe_voltage == SEC_VOLTAGE_13 ? 0 : 2)
+                          | (fe_tone == SEC_TONE_ON ? 1 : 0);
+
+        if( ioctl( i_frontend_handle, FE_DISEQC_SEND_MASTER_CMD,
+                   &cmd.cmd ) < 0 )
+        {
+            msg_Err( NULL, "ioctl FE_SEND_MASTER_CMD failed (%s)",
+                     strerror(errno) );
+            exit(1);
+        }
+
+        msleep(15000 + cmd.wait * 1000);
+
+        /* A or B simple diseqc ("diseqc-compatible") */
+        if( ioctl( i_frontend_handle, FE_DISEQC_SEND_BURST,
+                   /*((i_satno - 1) % 2) ? SEC_MINI_B :*/ SEC_MINI_A ) < 0 )
+        {
+            msg_Err( p_access, "ioctl FE_SEND_BURST failed (%d) %m",
+                     i_err );
+            return i_err;
+        }
+
+        msleep(15000);
+    }
+
     if ( ioctl( i_frontend, FE_SET_TONE, fe_tone ) < 0 )
     {
         msg_Err( NULL, "FE_SET_TONE failed (%s)", strerror(errno) );
         exit(1);
     }
 
-    /* TODO: Diseqc */
-
     msleep(50000);
 
     msg_Dbg( NULL, "tuning QPSK frontend to f=%d, srate=%d, v=%d, p=%d",
